/****************************************
 * Pilotage des 12 actionneurs de la ZIP
 * Interface-Z
 * ZIP Actuators
 *****************************************/

// Importer la library the Midibus
// http://smallbutdigital.com/themidibus.php
import themidibus.*; 
MidiBus myBus; 

int[] pwm = new int[4];
int[] relai = new int[4];
int[] servo = new int[4];
int compteur = 0;
PFont policeperso;

void setup()
{
  size(360, 200);
  noStroke();
  smooth();

  // Liste des peripheriques Midi disponibles sur l'ordinateur
  // Displaying Midi devices existing on the computer  
  MidiBus.list(); 

  // Ouverture de port (this, In, Out)
  // Choisir le numero du peripherique dans la liste
  // In et Out etant les numeros des peripheriques entrant et sortant
  // Open Midi port (this, In, Out)
  // Choose the appropriate Midi device from the list
  // In and Out being the corresponding In and Out devices
  myBus = new MidiBus(this, -1, 2);
  // -1 pour ne pas ouvrir ce port
  // -1 in order not to open this port

  policeperso = loadFont("BerlingAntiqua-BoldItalic-28.vlw");
  textFont(policeperso, 28);
  textAlign(CENTER);
}

void draw()
{
  background(0);
  compteur = (compteur + 1) % 1280;

  fill(255);
  text("ZIP", width/2, 136);
  text("Actionneurs", width/2, 160);
  text("PWM", 60, 30);
  text("Relais", width/2, 30);
  text("Servo", 300, 30);  

  /****************************************
   * Pilotage des 4 sorties Transistors PWM de la ZIP
   * PWM ZIP Actuators
   * sendControllerChange(canal, numero, valeur)
   * sendControllerChange(channel, number, value)
   *****************************************/
  // Envoie de commandes graduelles en boucle 
  // en decalage sur les 4 premieres sorties de la carte.
  // Sending values on the 4 first outputs of the card.
  for(int i=0; i<4; i=i+1) {
    pwm[i]=(compteur+i*10)%128;
    myBus.sendControllerChange(0, i, pwm[i]);   
    // Representation des commandes envoyees sur des sliders verts.
    // Displaying sent values on green sliders.
    fill(30, 200, 40, 200);
    rect(20+22*i, 40, 20, 128);
    fill(130, 240, 130, 200);
    rect(20+22*i, 40+127-pwm[i], 20, pwm[i]);

    fill(255);
    text(i, 30+22*i, 186);
  }

  /****************************************
   * Pilotage des 4 sorties Relais Tout ou Rien
   * On/Off ZIP Actuators
   * sendControllerChange(canal, numero, valeur)
   * sendControllerChange(channel, number, value)
   *****************************************/
  // Envoie de commandes On/Off en boucle 
  // en decalage sur les 4 sorties suivantes de la carte.
  // Sending values on the 4 next outputs of the card.
  for(int i=4; i<8; i=i+1) {
    relai[i-4]=int(((compteur+i*25)%128)/64);
    println(relai[i-4]);
    myBus.sendControllerChange(0, i, relai[i-4]*127);   
    // Representation des commandes envoyees sur des rectangles cyan.
    // Displaying sent values on blue rectangles.
    fill(30, 150, 150, 200);
    rect(50+22*i, 40, 20, 20);
    fill(130, 200, 200, relai[i-4]*200);
    rect(52+22*i, 42, 16, 16);

    fill(255);
    text(i, 60+22*i, 82);
  }  

  /****************************************
   * Pilotage des 4 sorties Servomoteurs
   * Servomotors ZIP Actuators
   * sendControllerChange(canal, numero, valeur)
   * sendControllerChange(channel, number, value)
   *****************************************/
  // Envoie de commandes On/Off en boucle 
  // en decalage sur les 4 dernieres sorties de la carte.
  // Sending values on the 4 last outputs of the card.
  for(int i=8; i<12; i=i+1) {
    servo[i-8]=int((compteur*0.2+i*20)%108)+10;
    myBus.sendControllerChange(0, i, servo[i-8]);   
    // Representation des commandes envoyees sur des sliders bleus.
    // Displaying sent values on blue sliders.
    fill(30, 50, 200, 200);
    rect(80+22*i, 40, 20, 128);
    fill(130, 150, 240, 200);
    rect(80+22*i, 40+127-servo[i-8], 20, servo[i-8]);

    fill(255);
    text(i, 90+22*i, 186);
  }
}

